@@ -7,16 +7,13 @@
 #ifndef DEBUGGER_H
 #define DEBUGGER_H
 
-#include <qtimer.h>
-#include <qdict.h>
-#include <qstringlist.h>
+#include <QSet>
+#include <QStringList>
+#include <list>
+#include <map>
 #include "envvar.h"
 #include "exprwnd.h"			/* some compilers require this */
 
-#ifdef HAVE_CONFIG_H
-#include "config.h"
-#endif
-
 class ExprWnd;
 class VarTree;
 struct ExprValue;
@@ -24,8 +21,8 @@ class ProgramTypeTable;
 class KTreeViewItem;
 class KConfig;
 class KConfigBase;
-class ProgramConfig;
-class QListBox;
+class KConfigGroup;
+class QListWidget;
 class RegisterInfo;
 class ThreadInfo;
 class DebuggerDriver;
@@ -34,7 +31,6 @@ class Breakpoint;
 struct DisassembledCode;
 struct MemoryDump;
 struct DbgAddr;
-class KProcess;
 
 
 class KDebugger : public QObject
@@ -44,7 +40,7 @@ public:
     KDebugger(QWidget* parent,		/* will be used as the parent for dialogs */
 	      ExprWnd* localVars,
 	      ExprWnd* watchVars,
-	      QListBox* backtrace);
+	      QListWidget* backtrace);
     ~KDebugger();
 
     /**
@@ -175,6 +171,19 @@ public:
      */
     bool runUntil(const QString& fileName, int lineNo);
 
+    /**
+     * Ask debugger for information about the specified line in the specified file.
+     *
+     * If \a addr is given, then it is used as a hint to position
+     * to position the cursor in the source window at that address
+     * if it belongs to the specified line.
+     * @param fileName The source file in which to set the breakpoint.
+     * @param lineNo The zero-based line number.
+     * @param addr An address that belongs to the name; can be empty.
+     * @return false if the command was not executed, e.g. because the
+     * debuggee is running at the moment.
+     */
+    bool infoLine(QString fileName, int lineNo, const DbgAddr& addr);
     /**
      * Set a breakpoint.
      *
@@ -344,7 +353,7 @@ protected:
     void stopDriver();
     void writeCommand();
     
-    QStringList m_watchEvalExpr;	/* exprs to evaluate for watch window */
+    std::list<QString> m_watchEvalExpr;	/* exprs to evaluate for watch window */
     std::list<Breakpoint> m_brkpts;
     QString m_memoryExpression;		/* memory location to watch */
     unsigned m_memoryFormat;		/* how that output should look */
@@ -355,8 +364,8 @@ protected:
     void handleRunCommands(const char* output);
     void updateAllExprs();
     void updateProgEnvironment(const QString& args, const QString& wd,
-			       const QDict<EnvVar>& newVars,
-			       const QStringList& newOptions);
+			       const std::map<QString,EnvVar>& newVars,
+			       const QSet<QString>& newOptions);
     void parseLocals(const char* output, std::list<ExprValue*>& newVars);
     void handleLocals(const char* output);
     bool handlePrint(CmdQueueItem* cmd, const char* output);
@@ -390,8 +399,8 @@ protected:
     void newBreakpoint(CmdQueueItem* cmd, const char* output);
     void updateBreakList(const char* output);
     bool stopMayChangeBreakList() const;
-    void saveBreakpoints(ProgramConfig* config);
-    void restoreBreakpoints(ProgramConfig* config);
+    void saveBreakpoints(KConfig* config);
+    void restoreBreakpoints(KConfig* config);
     bool enableDisableBreakpoint(BrkptIterator bp);
     bool deleteBreakpoint(BrkptIterator bp);
     bool conditionalBreakpoint(BrkptIterator bp,
@@ -408,14 +417,14 @@ protected:
     QString m_programArgs;
     QString m_remoteDevice;
     QString m_programWD;		/* working directory of gdb */
-    QDict<EnvVar> m_envVars;		/* environment variables set by user */
-    QStringList m_boolOptions;		/* boolean options */
+    std::map<QString,QString> m_envVars;	/* environment variables set by user */
+    QSet<QString> m_boolOptions;	/* boolean options */
     QStringList m_sharedLibs;		/* shared libraries used by program */
     ProgramTypeTable* m_typeTable;	/* known types used by the program */
-    ProgramConfig* m_programConfig;	/* program-specific settings (brkpts etc) */
+    KConfig* m_programConfig;		/* program-specific settings (brkpts etc) */
     void saveProgramSettings();
     void restoreProgramSettings();
-    QString readDebuggerCmd();
+    QString readDebuggerCmd(const KConfigGroup& g);
 
     // debugger process
     DebuggerDriver* m_d;
@@ -424,11 +433,11 @@ protected:
     QString m_statusMessage;
 
 protected slots:
-    void gdbExited(KProcess*);
+    void gdbExited();
     void slotInferiorRunning();
     void backgroundUpdate();
     void gotoFrame(int);
-    void slotExpanding(QListViewItem*);
+    void slotExpanding(QTreeWidgetItem*);
     void slotDeleteWatch();
     void slotValuePopup(const QString&);
     void slotDisassemble(const QString&, int);
@@ -546,7 +555,7 @@ signals:
 protected:
     ExprWnd& m_localVariables;
     ExprWnd& m_watchVariables;
-    QListBox& m_btWindow;
+    QListWidget& m_btWindow;
 
     // implementation helpers
 protected:
