@@ -7,9 +7,9 @@
 #ifndef EXPRWND_H
 #define EXPRWND_H
 
-#include "qlistview.h"
-#include <qlineedit.h>
-#include <qpixmap.h>
+#include <QTreeWidget>
+#include <QLineEdit>
+#include <QPixmap>
 #include <list>
 
 class ProgramTypeTable;
@@ -19,7 +19,7 @@ class ExprWnd;
 class QStringList;
 
 /*! \brief a variable's value is the tree of sub-variables */
-class VarTree : public QListViewItem
+class VarTree : public QTreeWidgetItem
 {
 public:
     enum VarKind { VKsimple, VKpointer, VKstruct, VKarray,
@@ -31,16 +31,15 @@ public:
 	NKaddress			//!< a dereferenced pointer
     };
     NameKind m_nameKind;
-    TypeInfo* m_type;			//!< the type of struct if it could be derived
+    const TypeInfo* m_type;			//!< the type of struct if it could be derived
     int m_exprIndex;			//!< used in struct value update
     bool m_exprIndexUseGuard;		//!< ditto; if guard expr should be used
     QString m_partialValue;		//!< while struct value update is in progress
 
-    VarTree(VarTree* parent, QListViewItem* after, ExprValue* v);
-    VarTree(ExprWnd* parent, QListViewItem* after, const QString& name);
+    VarTree(VarTree* parent, ExprValue* v);
+    VarTree(ExprWnd* parent, ExprValue* v);
     virtual ~VarTree();
 public:
-    virtual void paintCell(QPainter* p, const QColorGroup& cg, int column, int width, int align);
     QString computeExpr() const;
     bool isToplevelExpr() const;
     /** is this element an ancestor of (or equal to) child? */
@@ -52,16 +51,16 @@ public:
     /** find out the type of this value using the child values */
     void inferTypesOfChildren(ProgramTypeTable& typeTable);
     /** get the type from base class part */
-    TypeInfo* inferTypeFromBaseClass();
+    const TypeInfo* inferTypeFromBaseClass();
     /** returns whether the pointer is a wchar_t */
     bool isWcharT() const;
 
     QString getText() const { return text(0); }
-    void setText(const QString& t) { QListViewItem::setText(0, t); }
-    void setPixmap(const QPixmap& p) { QListViewItem::setPixmap(0, p); }
+    using QTreeWidgetItem::setText;
+    void setText(const QString& t) { QTreeWidgetItem::setText(0, t); }
+    void setPixmap(const QPixmap& p) { QTreeWidgetItem::setIcon(0, QIcon(p)); }
     QString value() const { return m_baseValue; }
-    VarTree* firstChild() const { return static_cast<VarTree*>(QListViewItem::firstChild()); }
-    VarTree* nextSibling() const { return static_cast<VarTree*>(QListViewItem::nextSibling()); }
+    VarTree* child(int i) const { return static_cast<VarTree*>(QTreeWidgetItem::child(i)); }
 
 private:
     void updateValueText();
@@ -113,11 +112,11 @@ signals:
 };
 
 
-class ExprWnd : public QListView
+class ExprWnd : public QTreeWidget
 {
     Q_OBJECT
 public:
-    ExprWnd(QWidget* parent, const QString& colHeader, const char* name);
+    ExprWnd(QWidget* parent, const QString& colHeader);
     ~ExprWnd();
 
     /** returns the list with the expressions at the topmost level */
@@ -150,9 +149,8 @@ public:
     /** tells whether the a value is currently edited */
     bool isEditing() const;
 
-    VarTree* firstChild() const { return static_cast<VarTree*>(QListView::firstChild()); }
-    VarTree* currentItem() const { return static_cast<VarTree*>(QListView::currentItem()); }
-    VarTree* selectedItem() const { return static_cast<VarTree*>(QListView::selectedItem()); }
+    VarTree* selectedItem() const { return static_cast<VarTree*>(QTreeWidget::currentItem()); }
+    VarTree* topLevelItem(int i) const { return static_cast<VarTree*>(QTreeWidget::topLevelItem(i)); }
 
 protected:
     void updateExprRec(VarTree* display, ExprValue* newValues, ProgramTypeTable& typeTable);
