@@ -6,27 +6,30 @@
 
 #ifndef REGWND_H
 #define REGWND_H
+#include <QTreeWidget>
 
-#include <qlistview.h>
 #include <list>
 #include <map>
 
-class QPopupMenu;
+class QMenu;
 class RegisterViewItem;
 class GroupingViewItem;
+class QContextMenuEvent;
 struct RegisterInfo;
 
 
-class RegisterView : public QListView
+class RegisterView : public QTreeWidget
 {
     Q_OBJECT
 public:
-    RegisterView(QWidget* parent, const char *name = 0L);
+    RegisterView(QWidget* parent);
     ~RegisterView();
 
+protected:
+    void contextMenuEvent(QContextMenuEvent*);
+
 protected slots:
-    void rightButtonClicked(QListViewItem*, const QPoint&, int);
-    void slotModeChange(int);
+    void slotModeChange(QAction*);
     void updateRegisters(const std::list<RegisterInfo>&);
 
 private:
@@ -34,7 +37,7 @@ private:
     void updateGroupVisibility();
     GroupingViewItem* findMatchingGroup(const QString& regName);
     GroupingViewItem* findGroup(const QString& groupName);
-    QPopupMenu* m_modemenu;
+    QMenu* m_modemenu;
     typedef std::map<QString,RegisterViewItem*> RegMap;
     RegMap m_registers;
 
