@@ -6,24 +6,22 @@
 
 #include "winstack.h"
 #include "sourcewnd.h"
-#include <qbrush.h>
-#include <qfileinfo.h>
-#include <qpopupmenu.h>
-#include <kapplication.h>
-#include <kmainwindow.h>
+#include "dbgdriver.h"
+#include <QFileInfo>
+#include <QMenu>
+#include <QContextMenuEvent>
+#include <QToolTip>
+#include <kglobal.h>
+#include <kxmlguiwindow.h>
+#include <kxmlguifactory.h>
 #include <klocale.h>			/* i18n */
-#ifdef HAVE_CONFIG_H
-#include "config.h"
-#endif
 #include "mydebug.h"
 
 
 
-WinStack::WinStack(QWidget* parent, const char* name) :
-	KTabWidget(parent, name),
+WinStack::WinStack(QWidget* parent) :
+	KTabWidget(parent),
 	m_pcLine(-1),
-	m_valueTip(this),
-	m_tipLocation(1,1,10,10),
 	m_tabWidth(0)
 {
     connect(&m_findDlg.m_buttonForward,
@@ -45,9 +43,9 @@ void WinStack::contextMenuEvent(QContextMenuEvent* e)
     do
 	top = top->parentWidget();
     while (!top->isTopLevel());
-    KMainWindow* mw = static_cast<KMainWindow*>(top);
-    QPopupMenu* m =
-	static_cast<QPopupMenu*>(mw->factory()->container("popup_files_empty", mw));
+    KXmlGuiWindow* mw = static_cast<KXmlGuiWindow*>(top);
+    QMenu* m =
+	static_cast<QMenu*>(mw->factory()->container("popup_files_empty", mw));
     m->exec(e->globalPos());
 }
 
@@ -83,7 +81,7 @@ void WinStack::activate(const QString& fileName, int lineNo, const DbgAddr& addr
 	}
     }
     // if this is not an absolute path name, make it one
-    activatePath(fi.absFilePath(), lineNo, address);
+    activatePath(fi.absoluteFilePath(), lineNo, address);
 }
 
 void WinStack::activateFile(const QString& fileName)
@@ -103,7 +101,7 @@ bool WinStack::activatePath(QString pathName, int lineNo, const DbgAddr& address
     }
     if (fw == 0) {
 	// not found, load it
-	fw = new SourceWindow(pathName, this, "fileWindow");
+	fw = new SourceWindow(pathName, this);
 
 	// slurp the file in
 	if (!fw->loadFile()) {
@@ -112,8 +110,8 @@ bool WinStack::activatePath(QString pathName, int lineNo, const DbgAddr& address
 	    return false;
 	}
 
-	addTab(fw, QFileInfo(pathName).fileName());
-	setTabToolTip(fw, pathName);
+	int idx = addTab(fw, QFileInfo(pathName).fileName());
+	setTabToolTip(idx, pathName);
 
 	connect(fw, SIGNAL(clickedLeft(const QString&,int,const DbgAddr&,bool)),
 		SIGNAL(toggleBreak(const QString&,int,const DbgAddr&,bool)));
@@ -129,7 +127,7 @@ bool WinStack::activatePath(QString pathName, int lineNo, const DbgAddr& address
 	// tab width
 	connect(this, SIGNAL(setTabWidth(int)), fw, SLOT(setTabWidth(int)));
 	fw->setTabWidth(m_tabWidth);
-	fw->setFocusPolicy(QWidget::WheelFocus);
+	fw->setFocusPolicy(Qt::WheelFocus);
 
 	// set PC if there is one
 	emit newFileLoaded();
@@ -147,7 +145,7 @@ bool WinStack::activateWindow(SourceWindow* fw, int lineNo, const DbgAddr& addre
 	fw->scrollTo(lineNo, address);
     }
 
-    showPage(fw);
+    setCurrentWidget(fw);
     fw->setFocus();
 
     return true;
@@ -213,12 +211,12 @@ void WinStack::setPC(bool set, const QString& fileName, int lineNo,
 
 SourceWindow* WinStack::windowAt(int i) const
 {
-    return static_cast<SourceWindow*>(page(i));
+    return static_cast<SourceWindow*>(widget(i));
 }
 
 SourceWindow* WinStack::activeWindow() const
 {
-    return static_cast<SourceWindow*>(currentPage());
+    return static_cast<SourceWindow*>(currentWidget());
 }
 
 QString WinStack::activeFileName() const
@@ -243,31 +241,39 @@ void WinStack::slotFindBackward()
 			     SourceWindow::findBackward);
 }
 
-void WinStack::maybeTip(const QPoint& p)
+bool WinStack::event(QEvent* evt)
 {
+    if (evt->type() != QEvent::ToolTip)
+	return KTabWidget::event(evt);
+
     SourceWindow* w = activeWindow();
     if (w == 0)
-	return;
+	return true;
 
+    QPoint p = static_cast<QHelpEvent*>(evt)->globalPos();
     // get the word at the point
     QString word;
     QRect r;
-    if (!w->wordAtPoint(w->mapFrom(this, p), word, r))
-	return;
+    if (!w->wordAtPoint(w->mapFromGlobal(p), word, r)) {
+	QToolTip::hideText();
+	return true;
+    }
 
     // must be valid
     assert(!word.isEmpty());
     assert(r.isValid());
 
     // remember the location
-    m_tipLocation = QRect(w->mapTo(this, r.topLeft()), r.size());
+    m_tipLocation = p;
+    m_tipRegion = QRect(w->mapTo(this, r.topLeft()), r.size());
 
     emit initiateValuePopup(word);
+    return true;
 }
 
 void WinStack::slotShowValueTip(const QString& tipText)
 {
-    m_valueTip.tip(m_tipLocation, tipText);
+    QToolTip::showText(m_tipLocation, tipText, this, m_tipRegion);
 }
 
 void WinStack::slotDisassembled(const QString& fileName, int lineNo,
@@ -365,33 +371,20 @@ void WinStack::slotClose()
 }
 
 
-ValueTip::ValueTip(WinStack* parent) :
-	QToolTip(parent)
-{
-}
-
-void ValueTip::maybeTip(const QPoint& p)
-{
-    WinStack* w = static_cast<WinStack*>(parentWidget());
-    w->maybeTip(p);
-}
-
-
 FindDialog::FindDialog() :
-	QDialog(0, "find", false),
-	m_searchText(this, "text"),
-	m_caseCheck(this, "case"),
-	m_buttonForward(this, "forward"),
-	m_buttonBackward(this, "backward"),
-	m_buttonClose(this, "close"),
-	m_layout(this, 8),
-	m_buttons(4)
+	QDialog(),
+	m_searchText(this),
+	m_caseCheck(this),
+	m_buttonForward(this),
+	m_buttonBackward(this),
+	m_buttonClose(this)
 {
-    setCaption(QString(kapp->caption()) + i18n(": Search"));
+    setWindowTitle(KGlobal::caption() + i18n(": Search"));
 
     m_searchText.setMinimumSize(330, 24);
     m_searchText.setMaxLength(10000);
     m_searchText.setFrame(true);
+    m_searchText.setFocus();
 
     m_caseCheck.setText(i18n("&Case sensitive"));
     m_caseCheck.setChecked(true);
@@ -400,34 +393,17 @@ FindDialog::FindDialog() :
     m_buttonBackward.setText(i18n("&Backward"));
     m_buttonClose.setText(i18n("Close"));
 
-    m_caseCheck.setMinimumSize(330, 24);
-
-    // get maximum size of buttons
-    QSize maxSize(80,30);
-    maxSize.expandedTo(m_buttonForward.sizeHint());
-    maxSize.expandedTo(m_buttonBackward.sizeHint());
-    maxSize.expandedTo(m_buttonClose.sizeHint());
-
-    m_buttonForward.setMinimumSize(maxSize);
-    m_buttonBackward.setMinimumSize(maxSize);
-    m_buttonClose.setMinimumSize(maxSize);
-
     connect(&m_buttonClose, SIGNAL(clicked()), SLOT(reject()));
 
     m_layout.addWidget(&m_searchText);
     m_layout.addWidget(&m_caseCheck);
     m_layout.addLayout(&m_buttons);
-    m_layout.addStretch(10);
+
     m_buttons.addWidget(&m_buttonForward);
-    m_buttons.addStretch(10);
     m_buttons.addWidget(&m_buttonBackward);
-    m_buttons.addStretch(10);
     m_buttons.addWidget(&m_buttonClose);
 
-    m_layout.activate();
-
-    m_searchText.setFocus();
-    resize( 350, 120 );
+    setLayout(&m_layout);
 }
 
 FindDialog::~FindDialog()
