@@ -366,7 +366,7 @@ XsldbgDriver::makeCmdString(DbgCommand cmd, QString strArg)
     }
 
     QString cmdString;
-    cmdString.sprintf(cmds[cmd].fmt, strArg.toLatin1().constData());
+    cmdString.sprintf(cmds[cmd].fmt, strArg.toUtf8().constData());
     return cmdString;
 }
 
@@ -470,9 +470,9 @@ XsldbgDriver::makeCmdString(DbgCommand cmd, QString strArg, int intArg)
             // must split off file name part
             strArg = QFileInfo(strArg).fileName();
         }
-        cmdString.sprintf(cmds[cmd].fmt, strArg.toLatin1().constData(), intArg);
+        cmdString.sprintf(cmds[cmd].fmt, strArg.toUtf8().constData(), intArg);
     } else {
-        cmdString.sprintf(cmds[cmd].fmt, intArg, strArg.toLatin1().constData());
+        cmdString.sprintf(cmds[cmd].fmt, intArg, strArg.toUtf8().constData());
     }
     return cmdString;
 }
@@ -489,8 +489,8 @@ XsldbgDriver::makeCmdString(DbgCommand cmd, QString strArg1,
 
     QString cmdString;
     cmdString.sprintf(cmds[cmd].fmt,
-		      strArg1.toLatin1().constData(),
-		      strArg2.toLatin1().constData());
+		      strArg1.toUtf8().constData(),
+		      strArg2.toUtf8().constData());
     return cmdString;
 }
 
@@ -698,7 +698,6 @@ static ExprValue *
 parseVar(const char *&s)
 {
     const char *p = s;
-    bool foundLocalVar = false;
     ExprValue *variable = 0L;
     QString name;
 
@@ -713,7 +712,6 @@ parseVar(const char *&s)
     }
 
     if (strncmp(p, " Local", 6) == 0) {
-        foundLocalVar = true;
         /* skip " Local" */
         p = p + 6;
         TRACE("Found local variable");
